@@ -76,7 +76,7 @@ def backup_all(ctx, config, filename):
     )
     if len(filename.parts) == 1:
         filename = Path(config.dumps_path) / filename
-    with autocleanpaper(Path(config.dumps_path) / str(uuid.uuid4())) as tmppath:
+    with autocleanpaper(Path(filename.parent) / str(uuid.uuid4())) as tmppath:
         tmppath.mkdir(exist_ok=True, parents=True)
         subprocess.check_output(["chown", str(config.owner_uid), tmppath])
         filepath_db = ctx.invoke(
