@@ -393,7 +393,6 @@ def fetch_modules(config, ctx, module):
     from .tools import rsync
     from .odoo_config import customs_dir
     from .module_tools import Modules, Module
-    from .module_tools import ModulesCache
 
     modules = Modules()
     odoosh = OdooShRepo(current_version())
@@ -414,8 +413,6 @@ def fetch_modules(config, ctx, module):
         manifest.rewrite()
 
     for module in module:
-        ModulesCache.reset_cache()
-
         oca_module = odoosh.find_module(module)
         todos = [oca_module.name]
         for dep in odoosh.find_dependant_modules(oca_module):
@@ -445,7 +442,10 @@ def _identify_duplicate_modules(check):
         ignore_paths.append((src / x).resolve().absolute())
 
     all_dirs = list(
-        filter(lambda x: ".git" not in x.parts, bashfind(path=src, type="d"), )
+        filter(
+            lambda x: ".git" not in x.parts,
+            bashfind(path=src, type="d"),
+        )
     )
 
     for x in sorted(check):
@@ -472,14 +472,6 @@ def _identify_duplicate_modules(check):
                     )
 
 
-@src.command
-@pass_config
-def clear_cache(config):
-    from .module_tools import ModulesCache
-
-    ModulesCache._clear_cache()
-
-
 @src.command
 @click.option("-f", "--fix-not-in-manifest", is_flag=True)
 @pass_config
@@ -516,4 +508,9 @@ def show_installed_modules(config, fix_not_in_manifest):
         manifest.rewrite()
 
 
-Commands.register(clear_cache)
+@src.command(name="pretty-print-manifest")
+def pretty_print_manifest():
+    from .odoo_config import MANIFEST
+
+    MANIFEST().rewrite()
+
